diff hgext/histedit.py @ 41206:6acbe86c6490

repair: move ui.history-editing-backup to [rewrite] section Since we have the "rewrite" section for general history-editing options, the backup option should be there.
author Yuya Nishihara <yuya@tcha.org>
date Sat, 12 Jan 2019 17:43:36 +0900
parents 99125b7fb93e
children 25cec00b333c
line wrap: on
line diff
--- a/hgext/histedit.py	Wed Jan 09 19:54:01 2019 -0800
+++ b/hgext/histedit.py	Sat Jan 12 17:43:36 2019 +0900
@@ -1680,8 +1680,8 @@
     fm.startitem()
     goal = _getgoal(opts)
     revs = opts.get('rev', [])
-    # experimental config: ui.history-editing-backup
-    nobackup = not ui.configbool('ui', 'history-editing-backup')
+    # experimental config: rewrite.backup-bundle
+    nobackup = not ui.configbool('rewrite', 'backup-bundle')
     rules = opts.get('commands', '')
     state.keep = opts.get('keep', False)